@@ -8,8 +8,8 @@ var indexSectionsWithContent =
   5: "j",
   6: "j",
   7: "j",
-  8: "j",
-  9: "j"
+  8: "bj",
+  9: "d"
 };
 
 var indexSectionNames =
@@ -22,8 +22,8 @@ var indexSectionNames =
   5: "typedefs",
   6: "enums",
   7: "enumvalues",
-  8: "defines",
-  9: "groups"
+  8: "groups",
+  9: "pages"
 };
 
 var indexSectionLabels =
@@ -36,7 +36,7 @@ var indexSectionLabels =
   5: "Typedefs",
   6: "Enumerations",
   7: "Enumerator",
-  8: "Macros",
-  9: "Modules"
+  8: "Modules",
+  9: "Pages"
 };
 
